@@ -2,11 +2,11 @@
 
 __author__ = """James Irving"""
 __email__ = 'james.irving.phd@gmail.com'
-__version__ = '0.2.25'
+__version__ = '0.3.13'
 
 from .default import *
 
-from fsds import datasets,jmi,quick_refs
+from fsds import datasets,jmi,quick_refs,pandemic
 
 
 # from fsds_100719 import datasets
